import Navigation from "@/components/navigation";
import Footer from "@/components/footer";
import SEOHead from "@/components/seo-head";
import { Link } from "wouter";
import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
// import OptimizedImage from "@/components/optimized-image";
import { lazy, Suspense } from "react";

// Lazy load contact form component
const ContactForm = lazy(() => import("@/components/contact-form"));
import {
  Building2,
  Heart,
  UserCheck,
  Phone,
  Mail,
  MapPin,
  Zap,
  Smartphone,
  Users,
  FileText,
  Bell,
} from "lucide-react";
import headerImagePath from "@assets/shutterstock_1155657649-Bristol-Design-owned_1749827733299.jpg";
import rugbyImagePath from "@assets/a06166_cc8fd39eb03c4718a688f4fbaead1146~mv2.avif";
import footballImagePath from "@assets/bristol-city-logo.avif";
import zooplaLogo from "@assets/Zoopla Logo.png";
import rightmoveLogo from "@assets/a06166_dec52144298b45abb542e28ed627bc63~mv2.png";
import goodlordLogo from "@assets/Goodlord LOGO.png";
import myDepositsLogo from "@assets/a06166_df2b3b5eab344b2da89895a01c3a8dc1~mv2.png";
import prsLogo from "@assets/a06166_7e230377a28b42279f5e58717a444528~mv2.png";
import iamPropertyLogo from "@assets/a06166_eb651cd9cd80499e82f739ab77cd1454~mv2.png";
import unihomesLogo from "@assets/a06166_2b579cf8066e4c91a95a0a332097de14~mv2.png";
import onTheMarketLogo from "@assets/a06166_71ccdacfe7d94e5da466d776b37070d1~mv2.png";
import chatgptLogo from "@assets/ChatGPT-Logo_1750104909504.jpg";
import airtableLogo from "@assets/Screenshot 2025-06-16 at 21.14.57_1750104901708.png";
import n8nLogo from "@assets/Screenshot 2025-06-16 at 21.14.41_1750104913700.png";
import adobeLogo from "@assets/Adobe_Creative_Cloud_rainbow_icon.svg_1750104955519.png";
import hybrLogo from "@assets/Screenshot 2025-06-16 at 21.17.36_1750105061585.png";
import rlgdLogo from "@assets/Badge_2_Real_Good_1750105127903.webp";

import bbImagePath from "@assets/BB.jpeg";
import bcfcImagePath from "@assets/BCFC.png";

export default function HomePage() {
  const homeSchema = {
    "@context": "https://schema.org",
    "@type": "RealEstateAgent",
    "name": "RG Property",
    "description": "Professional estate and letting agents in Bristol and Cardiff. AI-powered property services with 5-star Google reviews.",
    "url": "https://www.rgproperty.co.uk",
    "logo": "https://www.rgproperty.co.uk/logo.png",
    "address": {
      "@type": "PostalAddress",
      "addressLocality": "Bristol",
      "addressCountry": "GB"
    },
    "telephone": "+44117",
    "areaServed": ["Bristol", "Cardiff", "Bath", "Gloucester"],
    "serviceType": ["Property Sales", "Property Lettings", "Property Management", "Property Valuations"],
    "aggregateRating": {
      "@type": "AggregateRating",
      "ratingValue": "5",
      "reviewCount": "130"
    }
  };

  return (
    <div className="min-h-screen bg-white">
      <SEOHead
        title="RG Property - Bristol & Cardiff Estate Agents | 5★ Rated Property Services"
        description="Professional estate and letting agents in Bristol and Cardiff with 130+ 5-star reviews. AI-powered property sales, lettings, management and valuations. No hidden fees, competitive rates."
        keywords="estate agents Bristol, letting agents Bristol, estate agents Cardiff, property sales Bristol, property lettings Cardiff, property management, property valuations, Bristol estate agent, Cardiff letting agent"
        canonicalUrl="https://www.rgproperty.co.uk"
        ogImage="https://www.rgproperty.co.uk/og-image.jpg"
        schema={homeSchema}
      />
      <Navigation />
      
      {/* Cardiff Office Banner */}
      <div className="bg-gray-50 border-b border-gray-200 py-2">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <Link 
            href="/cardiff" 
            className="text-green-600 hover:text-green-700 font-medium text-sm transition-colors duration-200"
          >
            In Wales? Click here for our Cardiff office
          </Link>
        </div>
      </div>
      {/* Hero Section */}
      <section
        className="relative bg-gradient-to-br from-gray-800 via-gray-900 to-gray-800 text-white py-16 lg:py-24"
        style={{
          backgroundImage: `url(${headerImagePath})`,
          backgroundSize: "cover",
          backgroundPosition: "center",
        }}
      >
        <div className="absolute inset-0 bg-black opacity-60"></div>
        <div className="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="max-w-3xl">
            <h1 className="text-4xl lg:text-6xl font-bold mb-4 leading-tight">
              Professional Estate and Letting Agents <span className="text-red-500">Without the Red Tape</span>
            </h1>
            <p className="text-sm lg:text-base mb-6 text-gray-300">Bristol's only 5* agent with over 130 reviews</p>
            <p className="text-xl lg:text-2xl mb-8 text-gray-200">We promise to keep down costs for landlords, and vendors. Providing a high street agent, at online prices.</p>
            <div className="flex flex-col sm:flex-row gap-4">
              <Link href="/sales#book-valuation">
                <Button className="bg-red-600 hover:bg-red-700 text-white font-bold px-8 py-4 rounded-lg text-lg transition-colors duration-200">Book Free Valuation</Button>
              </Link>
              <Link href="/instant-valuation">
                <Button className="bg-transparent border-2 border-white text-white hover:bg-white hover:text-gray-900 font-bold px-8 py-4 rounded-lg text-lg transition-colors duration-200">Get Instant Online Valuation</Button>
              </Link>
            </div>
          </div>
        </div>
      </section>
      {/* Why Choose RG Section - Updated */}
      <section className="py-12 lg:py-16 bg-gray-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">Why Choose RG?</h2>
            <p className="text-lg text-gray-600 max-w-3xl mx-auto">
              We have over 30 years combined experience. We have done it all and we do it differently. Everything we do is
            </p>
            <p className="text-lg text-gray-600">
              <strong>Property focused</strong>, <strong>Personal to you</strong>, <strong>Performance based</strong>, and <strong>Service over profit.</strong>
            </p>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-8 mb-8">
            {/* AI Powered */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-red-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <Zap className="h-8 w-8 text-red-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">AI Powered</h3>
                <p className="text-gray-600 leading-relaxed">
                  We don't shy away from using AI, we mastered it instead. Our team no longer complete boring mundane tasks, 
                  and instead have way more time to focus on you, our client.
                </p>
              </CardContent>
            </Card>

            {/* Personal to the Client */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-red-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <Heart className="h-8 w-8 text-red-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">Personal to You</h3>
                <p className="text-gray-600 leading-relaxed">
                  You will be assigned a dedicated agent from start to finish, you have their WhatsApp, and they will not 
                  ignore you.
                </p>
              </CardContent>
            </Card>

            {/* Performance Based */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-red-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <Zap className="h-8 w-8 text-red-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">Performance Based</h3>
                <p className="text-gray-600 leading-relaxed">
                  No long tie-ins, No silly contracts. If we're not getting the results you want, you can leave whenever 
                  you like.
                </p>
              </CardContent>
            </Card>

            {/* Service over Profit */}
            <Card className="text-center shadow-lg hover:shadow-xl transition-shadow duration-200">
              <CardContent className="p-8">
                <div className="bg-red-100 rounded-full p-4 w-16 h-16 mx-auto mb-6 flex items-center justify-center">
                  <UserCheck className="h-8 w-8 text-red-600" />
                </div>
                <h3 className="text-xl font-semibold text-gray-900 mb-4">Service over Profit</h3>
                <p className="text-gray-600 leading-relaxed">
                  While major agents boast about billion-pound turnovers, we focus on exceptional customer service. 
                  Great service at fair fees - no hidden charges or rip-off costs.
                </p>
              </CardContent>
            </Card>
          </div>

          {/* RG Property Portal App Section */}
          <div className="bg-gradient-to-r from-gray-800 to-gray-900 rounded-2xl p-8 lg:p-12 text-white mb-12">
            <div className="max-w-6xl mx-auto text-center">
              <div className="flex items-center justify-center mb-6">
                <Smartphone className="h-12 w-12 text-red-500 mr-4" />
                <h3 className="text-3xl lg:text-4xl font-bold">The RG Portal</h3>
              </div>
              <p className="text-xl text-gray-200 mb-8">Sales and Lettings Made Simple - developed in-house for maximum security and convenience.</p>
              
              <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-6 text-left">
                <div className="bg-white bg-opacity-10 rounded-lg p-6">
                  <Users className="h-8 w-8 text-red-500 mb-3" />
                  <h4 className="font-semibold mb-2">Smart Viewing Management</h4>
                  <p className="text-gray-300 text-sm">Monitor viewings and feedback instantly. Choose your preferred viewing times and our system automatically books within your schedule.</p>
                </div>
                <div className="bg-white bg-opacity-10 rounded-lg p-6">
                  <FileText className="h-8 w-8 text-red-500 mb-3" />
                  <h4 className="font-semibold mb-2">Secure Document Hub</h4>
                  <p className="text-gray-300 text-sm">Upload ID and important documents directly. No more email limits or lost paperwork - everything stays organised and accessible.</p>
                </div>
                <div className="bg-white bg-opacity-10 rounded-lg p-6">
                  <Bell className="h-8 w-8 text-red-500 mb-3" />
                  <h4 className="font-semibold mb-2">24/7 Progress Tracking</h4>
                  <p className="text-gray-300 text-sm">Track your let or sale progression remotely with 7-day access. Stay informed every step of the way.</p>
                </div>
                <div className="bg-white bg-opacity-10 rounded-lg p-6">
                  <Phone className="h-8 w-8 text-red-500 mb-3" />
                  <h4 className="font-semibold mb-2">One Point of Contact</h4>
                  <p className="text-gray-300 text-sm">Your dedicated agent available throughout the process. No bouncing between departments or confusion.</p>
                </div>
                <div className="bg-white bg-opacity-10 rounded-lg p-6">
                  <UserCheck className="h-8 w-8 text-red-500 mb-3" />
                  <h4 className="font-semibold mb-2">7-Day Property Maintenance</h4>
                  <p className="text-gray-300 text-sm">Round-the-clock property maintenance support. Issues resolved quickly, any day of the week.</p>
                </div>
                <div className="bg-white bg-opacity-10 rounded-lg p-6">
                  <Mail className="h-8 w-8 text-red-500 mb-3" />
                  <h4 className="font-semibold mb-2">Always-On Communication</h4>
                  <p className="text-gray-300 text-sm">Our emails are monitored 7 days a week. Whatever happens, you're being looked after.</p>
                </div>
              </div>
            </div>
          </div>

          <div className="text-center">
            <h3 className="text-2xl font-bold text-gray-900 mb-4">
              We don't just sell or manage your property, we <span className="text-red-600">maximise your returns!</span>
            </h3>
            <p className="text-lg text-gray-600 max-w-3xl mx-auto mb-8">
              Whether you're selling or letting, we use cutting-edge technology and AI to achieve the best outcomes for your property investment.
            </p>
            
            {/* Service Navigation */}
            <div className="flex flex-col sm:flex-row gap-4 justify-center">
              <a href="#sales-fees">
                <Button className="bg-red-600 hover:bg-red-700 text-white font-bold px-8 py-4 rounded-lg text-lg transition-colors duration-200">
                  Jump to Sales
                </Button>
              </a>
              <a href="#lettings-services">
                <Button className="bg-red-600 hover:bg-red-700 text-white font-bold px-8 py-4 rounded-lg text-lg transition-colors duration-200">
                  Jump to Lettings
                </Button>
              </a>
              <a href="#mortgage-advice">
                <Button className="bg-red-600 hover:bg-red-700 text-white font-bold px-8 py-4 rounded-lg text-lg transition-colors duration-200">
                  Jump to Mortgages
                </Button>
              </a>
            </div>
          </div>
        </div>
      </section>
      {/* Our Lettings Services Section */}
      <section id="lettings-services" className="py-12 lg:py-16">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-10">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">OUR LETTINGS SERVICES</h2>
            <div className="w-24 h-1 bg-red-600 mx-auto"></div>
          </div>

          {/* Description Section - Above Packages */}
          <div className="bg-gradient-to-r from-gray-50 to-white rounded-xl p-6 mb-8 mx-4 border border-gray-100 shadow-sm">
            <div className="max-w-4xl mx-auto text-center">
              <h3 className="text-xl font-bold text-red-600 mb-4">Why are we any different?</h3>
              <div className="space-y-3 text-gray-700 leading-relaxed">
                <p className="text-base">
                  Between us, we've spent over 30 years in corporate companies, who regularly exploit landlords out of unfair and unjust fees year in, year out.
                </p>
                <p className="text-base">
                  We formed RG to give Landlords a better option, professional service with added perks, at a lower fee.
                </p>
                <p className="text-red-600 font-bold text-lg mt-4">
                  We will not be beaten on fee.
                </p>
              </div>
            </div>
          </div>
          
          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-6">
            {/* Simply Let */}
            <Card className="shadow-lg">
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">£475 <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="text-red-600 font-semibold bg-red-600 text-white px-3 py-1 text-xs">
                    SIMPLY LET
                  </div>
                </div>
                
                <p className="text-sm text-gray-600 mb-6">
                  For experienced landlords who just need a tenant found.
                </p>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Marketing</li>
                    <li>• Tenancy agreement</li>
                    <li>• Viewings</li>
                    <li>• Move in</li>
                    <li>• Advanced referencing</li>
                    <li>• Agreements & right to rent checks</li>
                    <li>• PEP & sanction checks</li>
                    <li>• References</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-2">
                    <strong>Extras:</strong> Rent Collection & Notices: £50+ VAT per notice
                  </p>
                  <p className="text-xs text-gray-600 mb-2">
                    Get <strong>Simply Let Pro</strong> for only <strong>£595 +VAT</strong>:
                  </p>
                  <ul className="text-xs text-gray-600 space-y-1 mb-4">
                    <li>• Inventory</li>
                    <li>• Deposit Registration</li>
                    <li>• Premium Listing</li>
                  </ul>
                  <Link href="/landlords#book-lettings-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Lettings Valuation
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>

            {/* Collect & Protect */}
            <Card className="relative overflow-hidden shadow-lg">
              <div className="absolute top-0 right-0 bg-red-600 text-white px-3 py-1 text-xs font-bold">
                POPULAR
              </div>
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">6.5% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-gray-800 text-white px-3 py-1 text-xs font-semibold">
                    COLLECT & PROTECT
                  </div>
                </div>
                
                <p className="text-sm text-gray-600 mb-6">
                  Includes everything in Simply Let, plus full protection and rent collection. Never worry about a missed payment again.
                </p>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Pro referencing, with advanced HMRC checks</li>
                    <li>• Inventory & check out reports</li>
                    <li>• Deposit registration</li>
                    <li>• Agreements & right to rent checks</li>
                    <li>• Rent collection & notices</li>
                    <li>• Rent protection guarantee</li>
                    <li>• Legal cover up to £100,000</li>
                    <li>• Full arrears chasing</li>
                    <li>• Rent paid same-day</li>
                    <li>• PEP & sanction checks</li>
                    <li>• Annual income and expenditure report</li>
                    <li>• Compliance monitoring</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-2">
                    Setup cost: <strong>£400 + VAT</strong>
                  </p>
                  <p className="text-xs text-green-600 font-semibold mb-4">
                    ✅ No Hidden Fees
                  </p>
                  <Link href="/landlords#book-lettings-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Lettings Valuation
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>

            {/* Full Management */}
            <Card className="shadow-lg">
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">10% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-gray-600 text-white px-3 py-1 text-xs font-semibold">
                    FULL MANAGEMENT
                  </div>
                </div>
                
                <p className="text-sm text-gray-600 mb-6">
                  Hands-free management & compliance, with peace of mind built in.
                </p>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Pro referencing</li>
                    <li>• Inventory & check out reports</li>
                    <li>• Deposit registration</li>
                    <li>• Agreements & right to rent checks</li>
                    <li>• Rent collection & notices</li>
                    <li>• Property management & compliance monitoring</li>
                    <li>• Annual renewals & rent review</li>
                    <li>• Annual income and expenditure report</li>
                    <li>• 3 property visits per year</li>
                    <li>• Rent & legal protection (£28/month or £300 one-off)</li>
                    <li>• PEP & sanction checks</li>
                    <li>• 7 days a week coverage</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-2">
                    Setup cost: <strong>£425 + VAT</strong>
                  </p>
                  <p className="text-xs text-green-600 font-semibold mb-4">
                    ✅ No Hidden Fees
                  </p>
                  <Link href="/landlords#book-lettings-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Lettings Valuation
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>

            {/* Prestige */}
            <Card className="relative overflow-hidden shadow-lg">
              <div className="absolute top-0 right-0 bg-yellow-500 text-white px-3 py-1 text-xs font-bold">
                ULTIMATE
              </div>
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">12.50% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-yellow-500 text-white px-3 py-1 text-xs font-semibold">
                    PRESTIGE MANAGEMENT
                  </div>
                </div>
                
                <p className="text-sm text-gray-600 mb-6">
                  The most comprehensive service with premium perks.
                </p>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Everything in full management</li>
                    <li>• Pro referencing</li>
                    <li>• Inventory & check out reports</li>
                    <li>• Deposit registration</li>
                    <li>• Agreements & right to rent checks</li>
                    <li>• Rent collection & notices</li>
                    <li>• Property management & compliance monitoring</li>
                    <li>• Annual renewals & rent review</li>
                    <li>• 4 property visits per year</li>
                    <li>• Annual income and expenditure report</li>
                    <li>• Rent & legal protection (up to £100,000)</li>
                    <li>• Rent protection coverage</li>
                    <li>• Dedicated point of contact</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-2">
                    Setup cost: <strong>£450 + VAT</strong>
                  </p>
                  <p className="text-xs text-green-600 font-semibold mb-4">
                    ✅ No Hidden Fees
                  </p>
                  <Link href="/landlords#book-lettings-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Lettings Valuation
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>
          </div>
          
          {/* View All Services Section - Below Package Cards */}
          <div className="text-center mt-12">
            <Link href="/landlords">
              <Button className="bg-red-600 hover:bg-red-700 text-white font-semibold px-8 py-4 rounded-lg text-lg transition-colors duration-200">
                View All Services
              </Button>
            </Link>
          </div>
        </div>
      </section>
      {/* Our Sales Services Section */}
      <section id="sales-fees" className="py-12 lg:py-16 bg-gray-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-10">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">OUR SALES SERVICES</h2>
            <div className="w-24 h-1 bg-red-600 mx-auto"></div>
          </div>

          {/* Description Section - Above Packages */}
          <div className="bg-gradient-to-r from-gray-50 to-white rounded-xl p-6 mb-8 mx-4 border border-gray-100 shadow-sm">
            <div className="max-w-4xl mx-auto text-center">
              <h3 className="text-xl font-bold text-red-600 mb-4">Why are we any different?</h3>
              <div className="space-y-3 text-gray-700 leading-relaxed">
                <p className="text-base">
                  With a dedicated member of staff at all times, WhatsApp communication, AI Automations and chasing there is no better agent to sell your property.
                </p>
                <p className="text-base">
                  We have kept fees fair and given you full autonomy of how we sell your property.
                </p>
                <p className="text-red-600 font-bold text-lg mt-4">
                  We will not be beaten on service.
                </p>
              </div>
            </div>
          </div>
          
          <div className="grid md:grid-cols-3 gap-6 mb-12">
            {/* Traditional */}
            <Card className="shadow-lg">
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">0.8% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-red-600 text-white px-3 py-1 text-xs font-semibold">
                    TRADITIONAL
                  </div>
                </div>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Professionally edited marketing photos</li>
                    <li>• Rightmove & Zoopla listing</li>
                    <li>• Social media marketing package</li>
                    <li>• No sale no fee</li>
                    <li>• Dedicated point of contact</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-4">
                    Subject to minimum fee of <strong>£1,500 + VAT</strong>
                  </p>
                  <Link href="/sales#book-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Sales Valuation
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>

            {/* Prestige */}
            <Card className="relative overflow-hidden shadow-lg">
              <div className="absolute top-0 right-0 bg-gray-800 text-white px-3 py-1 text-xs font-bold">
                POPULAR
              </div>
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">1% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-gray-800 text-white px-3 py-1 text-xs font-semibold">
                    PRESTIGE
                  </div>
                </div>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Professional photography</li>
                    <li>• 4K video tour</li>
                    <li>• Premium Rightmove & Zoopla listing</li>
                    <li>• Paid ad social media marketing package</li>
                    <li>• Free speed tour</li>
                    <li>• No sale no fee</li>
                    <li>• Dedicated point of contact</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-4">
                    Subject to minimum fee of <strong>£2,000 + VAT</strong>
                  </p>
                  <Link href="/sales#book-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Sales Valuation
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>

            {/* Elite */}
            <Card className="shadow-lg">
              <CardContent className="p-6 text-center flex flex-col h-full">
                <div className="mb-6">
                  <div className="text-4xl font-bold text-gray-900 mb-1 flex items-center justify-center gap-2">1.2% <span className="text-lg text-gray-600">+VAT</span></div>
                  <div className="bg-yellow-600 text-white px-3 py-1 text-xs font-semibold">
                    ELITE
                  </div>
                </div>
                
                <div className="text-left space-y-2 mb-6 flex-grow">
                  <ul className="text-sm text-gray-700 space-y-1">
                    <li>• Professional photography</li>
                    <li>• 4K cinematic video tour (guaranteed 10k+ views)</li>
                    <li>• Aerial drone footage</li>
                    <li>• Featured Rightmove & Zoopla listing</li>
                    <li>• Ultimate social media marketing package</li>
                    <li>• Free speed tour</li>
                    <li>• No sale no fee</li>
                    <li>• Dedicated point of contact</li>
                  </ul>
                </div>
                
                <div className="border-t pt-4 mt-auto">
                  <p className="text-xs text-gray-600 mb-4">
                    Subject to minimum fee of <strong>£2,500 + VAT</strong>
                  </p>
                  <Link href="/sales#book-valuation">
                    <Button className="w-full bg-red-600 hover:bg-red-700 text-white font-semibold py-2 px-4 rounded-lg text-sm transition-colors duration-200">
                      Book Sales Valuation
                    </Button>
                  </Link>
                </div>
              </CardContent>
            </Card>
          </div>

          {/* View All Services Section - Below Package Cards */}
          <div className="text-center mt-12">
            <Link href="/sales">
              <Button className="bg-red-600 hover:bg-red-700 text-white font-semibold px-8 py-4 rounded-lg text-lg transition-colors duration-200">
                View All Services
              </Button>
            </Link>
          </div>
        </div>
      </section>

      {/* Mortgage Advice Section */}
      <section id="mortgage-advice" className="py-12 lg:py-16 bg-red-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center max-w-4xl mx-auto">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-6">
              Need Mortgage Advice Without the Fees?
            </h2>
            <p className="text-lg text-gray-700 mb-6 leading-relaxed">
              Most mortgage advisors charge hefty fees for advice AND applications, even though they already receive 
              substantial commissions from lenders. Why pay twice for the same service?
            </p>
            <p className="text-xl font-semibold text-red-600 mb-6">
              RG Property never charges a fee - always free advice.
            </p>
            <p className="text-sm text-gray-600 mb-8">
              *Advice provided by Linear Network. Your home may be repossessed if you do not keep up repayments on your mortgage. Lender fees may apply.
            </p>
            <div className="flex flex-col sm:flex-row gap-4 justify-center">
              <Link href="/mortgages">
                <Button className="bg-red-600 hover:bg-red-700 text-white font-bold px-8 py-4 rounded-lg text-lg transition-colors duration-200">
                  Learn More About Our Free Service
                </Button>
              </Link>
              <Link href="/mortgages#book-mortgage-appointment">
                <Button className="bg-transparent border-2 border-red-600 text-red-600 hover:bg-red-600 hover:text-white font-bold px-8 py-4 rounded-lg text-lg transition-colors duration-200">
                  Book Free Consultation
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Tech Partners Section */}
      <section className="py-10 lg:py-14 bg-[#ffffff]">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-8">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">Tech & Partnerships</h2>
            <p className="text-lg text-gray-600">We partner with the best platforms to ensure top service</p>
          </div>
          
          <div className="grid grid-cols-2 md:grid-cols-4 lg:grid-cols-8 gap-6">
            {[
              { name: "Zoopla", logo: zooplaLogo },
              { name: "Rightmove", logo: rightmoveLogo },
              { name: "Goodlord", logo: goodlordLogo },
              { name: "MyDeposits", logo: myDepositsLogo },
              { name: "Property Redress Scheme", logo: prsLogo },
              { name: "iamproperty", logo: iamPropertyLogo },
              { name: "Unihomes", logo: unihomesLogo },
              { name: "OnTheMarket", logo: onTheMarketLogo },
              { name: "ChatGPT", logo: chatgptLogo },
              { name: "Airtable", logo: airtableLogo },
              { name: "RLGD Coffee", logo: rlgdLogo, url: "https://rlgd.co.uk" },
              { name: "Adobe Creative Cloud", logo: adobeLogo },
              { name: "Hybr", logo: hybrLogo },
              { name: "n8n", logo: n8nLogo },
              { name: "Bristol Bears Rugby", logo: bbImagePath },
              { name: "Bristol City Football Club", logo: bcfcImagePath }
            ].map((partner) => (
              <Card key={partner.name} className="shadow-sm">
                <CardContent className="p-4 flex items-center justify-center h-20">
                  {partner.url ? (
                    <a 
                      href={partner.url} 
                      target="_blank" 
                      rel="noopener noreferrer"
                      className="inline-block hover:scale-105 transition-transform duration-200"
                    >
                      <div className={`flex items-center justify-center ${
                        partner.name === "RLGD Coffee" 
                          ? "bg-black rounded-full w-16 h-16" 
                          : ""
                      }`}>
                        <img 
                          src={partner.logo} 
                          alt={partner.name} 
                          className={`object-contain ${
                            partner.name === "Airtable" 
                              ? "max-h-16 max-w-full" 
                              : partner.name === "RLGD Coffee"
                              ? "max-h-14 max-w-14"
                              : "max-h-12 max-w-full"
                          }`}
                          style={partner.name === "Airtable" ? { 
                            backgroundColor: 'transparent',
                            mixBlendMode: 'multiply'
                          } : {}}
                          loading="lazy"
                        />
                      </div>
                    </a>
                  ) : (
                    <div className={`flex items-center justify-center ${
                      partner.name === "RLGD Coffee" 
                        ? "bg-black rounded-full w-16 h-16" 
                        : ""
                    }`}>
                      <img 
                        src={partner.logo} 
                        alt={partner.name} 
                        className={`object-contain ${
                          partner.name === "Airtable" 
                            ? "max-h-16 max-w-full" 
                            : partner.name === "RLGD Coffee"
                            ? "max-h-14 max-w-14"
                            : "max-h-12 max-w-full"
                        }`}
                        style={partner.name === "Airtable" ? { 
                          backgroundColor: 'transparent',
                          mixBlendMode: 'multiply'
                        } : {}}
                        loading="lazy"
                      />
                    </div>
                  )}
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Contact Section */}
      <Suspense fallback={<div className="py-16 text-center">Loading contact form...</div>}>
        <ContactForm />
      </Suspense>
      <Footer />
    </div>
  );
}